/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.camilstaps.webshop;

import com.camilstaps.webshop.article.Article;
import com.camilstaps.webshop.payment.IDeal;
import com.camilstaps.webshop.payment.PaymentMethod;
import java.util.ArrayList;
import java.util.List;

/**
 * A Cart holds articles and can be checked out
 * @author Camil Staps
 */
public class Cart extends ArrayList<Article> {

    /**
     * If no payment method gets set by the user, iDeal will be used
     */
    private PaymentMethod paymentMethod = new IDeal();
    
    /**
     * The price of the articles without shipping costs
     * @return 
     */
    public double getSubtotal() {
        double total = 0;
        for (Article a : this) {
            total += a.getPrice();
        }
        return total;
    }
    
    /**
     * The summed shipping costs of all articles
     * The same cost will only be charged once
     * @return 
     */
    public double getShippingCosts() {
        List<Double> seenCosts = new ArrayList<>();
        double total = 0;
        for (Article a : this) {
            if (!seenCosts.contains(a.getShippingCosts())) {
                seenCosts.add(a.getShippingCosts());
                total += a.getShippingCosts();
            }
        }
        return total;
    }
    
    /**
     * Get the total amount to pay
     * @return 
     */
    public double getTotal() {
        return getSubtotal() + getShippingCosts();
    }
    
    /**
     * Set the Payment Method
     * @param paymentMethod 
     */
    public void setPaymentMethod(PaymentMethod paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    /**
     * Pay using the set payment method (see { @link self#setPaymentMethod }.
     * @return 
     */
    public boolean pay() {
        System.out.println("Subtotal : " + getSubtotal());
        System.out.println("Shipping : " + getShippingCosts());
        System.out.println("TOTAL    : " + getTotal());
        if (paymentMethod.pay(getTotal())) {
            clear();
            return true;
        }
        return false;
    }
    
}
