/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.camilstaps.webshop.payment;

import java.util.Scanner;

/**
 * PaymentMethod using iDeal
 * @author camilstaps
 */
public class IDeal implements PaymentMethod {
    
    /**
     * Bank details
     */
    private String bank, accountNr, pincode;
    
    /**
     * Scanner to get user input from if bank details are missing
     */
    private final Scanner sc = new Scanner(System.in);
    
    /**
     * Create object without specifying data (user will be asked for needed data
     * on {@link self#pay }).
     */
    public IDeal() {
    }
    
    /**
     * Create object with specified data
     * @param bank
     * @param accountNr
     * @param pincode 
     */
    public IDeal(String bank, String accountNr, String pincode) {
        this.bank = bank;
        this.accountNr = accountNr;
        this.pincode = pincode;
    }
    
    /**
     * Make sure bank != null
     */
    private void ensureBank() {
        if (bank != null) return;
        System.out.print("Bank: ");
        bank = sc.nextLine();
    }
    
    /**
     * Make sure accountNr != null
     */
    private void ensureAccountNr() {
        if (accountNr != null) return;
        System.out.print("Account nr: ");
        accountNr = sc.nextLine();
    }
    
    /**
     * Make sure pincode != null
     */
    private void ensurePincode() {
        if (pincode != null) return;
        System.out.print("Pincode: ");
        pincode = sc.nextLine();
    }

    @Override
    public boolean pay(double amount) {
        ensureBank();
        ensureAccountNr();
        ensurePincode();
        System.out.println("€" + amount + " paid with iDeal: \n" + bank + " : " + accountNr + " (" + pincode + ")");
        return true;
    }
    
}
